<?php

/**
 * This is the model class for table "drug".
 *
 * The followings are the available columns in table 'drug':
 * @property string $drug_name
 * @property string $drug_id
 *
 * The followings are the available model relations:
 * @property target[] $targets
 */
class Drug extends CActiveRecord
{

    /**
     * Returns the static model of the specified AR class.
     * @param string $className active record class name.
     * @return Drug the static model class
     */
    public static function model($className=__CLASS__)
    {
        return parent::model($className);
    }

    /**
     * @return string the associated database table name
     */
    public function tableName()
    {
        return 'drug';
    }

    /**
     * @return array validation rules for model attributes.
     */
    public function rules()
    {
        // NOTE: you should only define rules for those attributes that
        // will receive user inputs.
        return array(
            array('drug_name, drug_indication, drug_synonym, drug_brand', 'required'),
            array('drug_name', 'length', 'max' => 100),
            array('drug_id', 'length', 'max' => 60),
            array('drug_indication', 'length', 'max' => 1700),
            array('drug_synonym', 'length', 'max' => 120),
            array('drug_brand', 'length', 'max' => 40),
            // The following rule is used by search().
            // Please remove those attributes that should not be searched.
            array('drug_name, drug_id, drug_indication, drug_synonym, drug_brand, target_id', 'safe', 'on' => 'search'),
        );
    }

    /**
     * @return array relational rules.
     */
    public function relations()
    {
        // NOTE: you may need to adjust the relation name and the related
        // class name for the relations automatically generated below.
        return array(
            'targets' => array(self::MANY_MANY, 'Target', 'Drug_has_target(drug_id, target_id)')
        );
    }

    /*
      public function targetsToString()
      {
      $targets = $this->targets;
      if ($targets)
      {
      $string = '';
      foreach($targets as $target) {
      $string .= $targets->target_id . ', ';
      }
      return substr($string,0,strlen($string)-1);
      }
      return null;
      }

      /**
     * @return array customized attribute labels (name=>label)
     */

    public function attributeLabels()
    {
        return array(
            'drug_name' => 'Drug Name',
            'drug_id' => 'Drug ID',
            'drug_indication' => 'Drug Indication',
            'drug_synonym' => 'Drug Synonym',
            'drug_brand' => 'Drug Brand',
            'target_id' => 'Target ID',
        );
    }

    /*
      function behaviors() {
      return array(
      'relatedsearch'=>array(
      'class'=>'RelatedSearchBehavior',
      'relations'=>array(
      'drug_id'=>'drug.drug_id',
      'drug_name'=>'drug.drug_name',
      'target_id'=>'target.target_id',
      // Field where search value is different($this->deviceid)
      /*'targets'=>array(
      'field'=>'target.target_id',
      'searchvalue'=>'target_id'
      ),
      // Next line describes a field we do not search,
      // but we define it here for convienience

      ),
      ),
      );
      }
     */

    /**
     * Retrieves a list of models based on the current search/filter conditions.
     * @return CActiveDataProvider the data provider that can return the models based on the search/filter conditions.
     */
    public function search()
    {
        // Warning: Please modify the following code to remove attributes that
        // should not be searched.

        $criteria = new CDbCriteria;

        $criteria->compare('drug_name', $this->drug_name, true);
        $criteria->compare('drug_id', $this->drug_id, true);
        $criteria->compare('drug_indication', $this->drug_indication, true);
        $criteria->compare('drug_synonym', $this->drug_synonym, true);
        $criteria->compare('drug_brand', $this->drug_brand, true);

        return new CActiveDataProvider($this, array(
                'criteria' => $criteria,
            ));
    }

}
