<?php

/**
 * This is the model class for table "target".
 *
 * The followings are the available columns in table 'target':
 * @property string $target_id
 * @property string $target_name
 *
 * The followings are the available model relations:
 * @property drug[] $drugs
 */
class Target extends CActiveRecord
{

    /**
     * Returns the static model of the specified AR class.
     * @param string $className active record class name.
     * @return Target the static model class
     */
    public static function model($className=__CLASS__)
    {
        return parent::model($className);
    }

    /**
     * @return string the associated database table name
     */
    public function tableName()
    {
        return 'target';
    }

    /**
     * @return array validation rules for model attributes.
     */
    public function rules()
    {
        // NOTE: you should only define rules for those attributes that
        // will receive user inputs.
        return array(
            array('target_name', 'required'),
            array('target_id', 'length', 'max' => 40),
            array('target_name', 'length', 'max' => 70),
            // The following rule is used by search().
            // Please remove those attributes that should not be searched.
            array('target_id, target_name', 'safe', 'on' => 'search'),
        );
    }

    /**
     * @return array relational rules.
     */
    public function relations()
    {
        // NOTE: you may need to adjust the relation name and the related
        // class name for the relations automatically generated below.
        return array(
            'drugs' => array(self::MANY_MANY, 'Drug', 'Drug_has_target(target_id, drug_id)')
        );
    }

    /**
     * @return array customized attribute labels (name=>label)
     */
    public function attributeLabels()
    {
        return array(
            'target_id' => 'Target',
            'target_name' => 'Target Name',
        );
    }

    /**
     * Retrieves a list of models based on the current search/filter conditions.
     * @return CActiveDataProvider the data provider that can return the models based on the search/filter conditions.
     */
    public function search()
    {
        // Warning: Please modify the following code to remove attributes that
        // should not be searched.

        $criteria = new CDbCriteria;

        $criteria->compare('target_id', $this->target_id, true);
        $criteria->compare('target_name', $this->target_name, true);

        return new CActiveDataProvider($this, array(
                'criteria' => $criteria,
            ));
    }

}
